@@ -32,6 +32,7 @@ use v5.10;
 # Half of the size used in the "sliding window" for detecting bad
 # licenses like GFDL with invariant sections.
 # NB: Keep in sync cruft-gfdl-fp-sliding-win/pre_build.
+# not less than 8192 for source missing
 use constant BLOCKSIZE => 16_384;
 
 use Lintian::Data;
@@ -304,7 +305,7 @@ my @file_checks = (
     [qr,^(.+/)?\.arch-inventory$,       => 'arch-inventory-file'],
     [qr,^(.+/)?\.hgtags$,               => 'hg-tags-file'],
     [qr,^(.+/)?\.\#(.+?)\.\d+(\.\d+)*$, => 'cvs-conflict-copy'],
-    [qr,^(.+/)?(.+?)\.(r\d+)$,          => 'svn-conflict-file'],
+    [qr,^(.+/)?(.+?)\.(r[1-9]\d*)$,     => 'svn-conflict-file'],
     [qr,\.(orig|rej)$,                  => 'patch-failure-file', 1],
     [qr,((^|/)\.[^/]+\.swp|~)$,         => 'editor-backup-file', 1],
 );
@@ -645,7 +646,9 @@ sub find_cruft {
         if ($basename =~ /\blenn?a\b/i) {
             if(    $file_info =~ /\bimage\b/i
                 or $file_info =~ /^Matlab v\d+ mat/i
-                or $file_info =~ /\bbitmap\b/i) {
+                or $file_info =~ /\bbitmap\b/i
+                or $file_info =~ /^PDF Document\b/i
+                or $file_info =~ /^Postscript Document\b/i) {
                 tag 'license-problem-non-free-img-lenna', $name;
             }
 
@@ -816,9 +819,7 @@ sub full_text_check {
     }
 
     # some js file comments are really really long
-    my $sfd
-      = Lintian::SlidingWindow->new($fd, \&lc_block,
-        _is_javascript_but_not_minified($name) ? 8092 : 4096);
+    my $sfd= Lintian::SlidingWindow->new($fd, \&lc_block, BLOCKSIZE);
     my %licenseproblemhash;
 
     # we try to read this file in block and use a sliding window
@@ -1029,7 +1030,7 @@ sub _check_gfdl_license_problem {
                 my $applytag = $gfdl_data->{'tag'};
                 if(defined($applytag)) {
                     unless(defined($licenseproblemhash->{$applytag})) {
-                        # lie will allow to check more block
+                        # lie will allow checking more blocks
                         _tag_gfdl($applytag, $name, $gfdlsections);
                         $licenseproblemhash->{$applytag} = 1;
                         return 0;
