@@ -30,6 +30,8 @@ use Lintian::Util qw(drain_pipe fail is_string_utf8_encoded open_gz
   signal_number2name strip normalize_pkg_path);
 use Lintian::SlidingWindow;
 
+use constant BLOCKSIZE => 16_384;
+
 my $FONT_PACKAGES = Lintian::Data->new('files/fonts', qr/\s++/);
 my $TRIPLETS = Lintian::Data->new('files/triplets', qr/\s++/);
 my $LOCALE_CODES = Lintian::Data->new('files/locale-codes', qr/\s++/);
@@ -444,13 +446,13 @@ sub run {
             # /etc/apt
             if ($fname =~ m,^etc/apt/,) {
                 # -----------------/etc/apt/preferences
-                if ($fname =~ m,^etc/apt/preferences(?:\.d/)?,) {
+                if ($fname =~ m,^etc/apt/preferences(?:$|\.d/),) {
                     unless ($source_pkg eq 'apt') {
                         tag 'package-install-apt-preferences', $file;
                     }
                 }
                 # -----------------/etc/apt/sources
-                if ($fname =~ m,^etc/apt/sources(?:\.d/)?,) {
+                if ($fname =~ m,^etc/apt/sources\.list(?:$|\.d/),) {
                     unless ($source_pkg eq 'apt') {
                         tag 'package-install-apt-sources', $file;
                     }
@@ -567,7 +569,7 @@ sub run {
                     }
 
                     # zero byte file in /usr/share/doc/
-                    if ($file->size == 0 and $file->is_regular_file) {
+                    if ($file->is_regular_file and $file->size == 0) {
                      # Exceptions: examples may contain empty files for various
                      # reasons, Doxygen generates empty *.map files, and Python
                      # uses __init__.py to mark module directories.
@@ -584,8 +586,8 @@ sub run {
                     # 276 is 255 bytes (maximal length for a filename)
                     # + gzip overhead
                     if (    $fname =~ m,.gz$,
+                        and $file->is_regular_file
                         and $file->size <= 276
-                        and $file->is_file
                         and $file->file_info =~ m/gzip compressed/) {
                         my $fd = $file->open_gz;
                         my $f = <$fd>;
@@ -1091,7 +1093,7 @@ sub run {
                 my $fd = $file->open;
                 while (<$fd>) {
                     if (
-                        m{ (?:do|require)\s+(?:'|") # do/require
+                        m{ (?:do|require)\s+['"] # do/require
 
                           # Huge list of perl4 modules...
                           (abbrev|assert|bigfloat|bigint|bigrat
@@ -1101,7 +1103,7 @@ sub run {
                           |open2|open3|pwd|shellwords|stat|syslog
                           |tainted|termcap|timelocal|validate)
                           # ... so they end with ".pl" rather than ".pm"
-                          \.pl(?:'|")
+                          \.pl['"]
                }xsm
                       ) {
                         tag 'perl-module-uses-perl4-libs-without-dep',
@@ -2038,7 +2040,7 @@ sub detect_privacy_breach {
 
     my $fd = $file->open(':raw');
 
-    my $sfd = Lintian::SlidingWindow->new($fd,sub { $_=lc($_); });
+    my $sfd = Lintian::SlidingWindow->new($fd,sub { $_=lc($_); },BLOCKSIZE);
 
     while (my $block = $sfd->readwindow()) {
         # try generic fragment tagging
